==> jc-1.4.0.tar.gz: javax/transaction/RollbackException.h <==
// public class javax.transaction.RollbackException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8165e3e2ab3c0ae8 javax_transaction_RollbackException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_transaction_RollbackException_H_
#define _JC_javax_transaction_RollbackException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_RollbackException$sub_refs	_jc_javax_transaction_RollbackException$sub_refs;
typedef struct _jc_javax_transaction_RollbackException$sub_nonrefs	_jc_javax_transaction_RollbackException$sub_nonrefs;
typedef struct _jc_javax_transaction_RollbackException$refs	_jc_javax_transaction_RollbackException$refs;
typedef struct _jc_javax_transaction_RollbackException$nonrefs	_jc_javax_transaction_RollbackException$nonrefs;
typedef struct _jc_javax_transaction_RollbackException$object	_jc_javax_transaction_RollbackException$object;

typedef const struct _jc_javax_transaction_RollbackException$vmethods	_jc_javax_transaction_RollbackException$vmethods;
typedef const struct _jc_javax_transaction_RollbackException$vtable	_jc_javax_transaction_RollbackException$vtable;
typedef const struct _jc_javax_transaction_RollbackException$vtype	_jc_javax_transaction_RollbackException$vtype;

// Constructors
extern void _jc_javax_transaction_RollbackException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_RollbackException$object *);
extern void _jc_javax_transaction_RollbackException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_RollbackException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_transaction_RollbackException$vmethods {
};

// Vtable
struct _jc_javax_transaction_RollbackException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_transaction_RollbackException$vmethods	javax_transaction_RollbackException;
};

// Vtype
struct _jc_javax_transaction_RollbackException$vtype {
	_jc_type			type;
	_jc_javax_transaction_RollbackException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_RollbackException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_RollbackException$refs {
    _jc_javax_transaction_RollbackException$sub_refs	javax_transaction_RollbackException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_RollbackException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_RollbackException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_transaction_RollbackException$sub_nonrefs	javax_transaction_RollbackException;
};

// Object instance structure
struct _jc_javax_transaction_RollbackException$object {
	_jc_javax_transaction_RollbackException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_RollbackException$vtype	*vtype;
	_jc_javax_transaction_RollbackException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_RollbackException$vtype _jc_javax_transaction_RollbackException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_RollbackException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_RollbackException$class_object;

#endif	/* _JC_javax_transaction_RollbackException_H_ */

==> jc-1.4.6.tar.gz: javax/transaction/RollbackException.h <==
// public class javax.transaction.RollbackException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8165e3e2ab3c0ae8 javax_transaction_RollbackException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_transaction_RollbackException_H_
#define _JC_javax_transaction_RollbackException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_RollbackException$sub_refs	_jc_javax_transaction_RollbackException$sub_refs;
typedef struct _jc_javax_transaction_RollbackException$sub_nonrefs	_jc_javax_transaction_RollbackException$sub_nonrefs;
typedef struct _jc_javax_transaction_RollbackException$refs	_jc_javax_transaction_RollbackException$refs;
typedef struct _jc_javax_transaction_RollbackException$nonrefs	_jc_javax_transaction_RollbackException$nonrefs;
typedef struct _jc_javax_transaction_RollbackException$object	_jc_javax_transaction_RollbackException$object;

typedef const struct _jc_javax_transaction_RollbackException$vmethods	_jc_javax_transaction_RollbackException$vmethods;
typedef const struct _jc_javax_transaction_RollbackException$vtable	_jc_javax_transaction_RollbackException$vtable;
typedef const struct _jc_javax_transaction_RollbackException$vtype	_jc_javax_transaction_RollbackException$vtype;

// Constructors
extern void _jc_javax_transaction_RollbackException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_RollbackException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_transaction_RollbackException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_RollbackException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_transaction_RollbackException$vmethods {
};

// Vtable
struct _jc_javax_transaction_RollbackException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_transaction_RollbackException$vmethods	javax_transaction_RollbackException;
};

// Vtype
struct _jc_javax_transaction_RollbackException$vtype {
	_jc_type			type;
	_jc_javax_transaction_RollbackException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_RollbackException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_RollbackException$refs {
    _jc_javax_transaction_RollbackException$sub_refs	javax_transaction_RollbackException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_RollbackException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_RollbackException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_transaction_RollbackException$sub_nonrefs	javax_transaction_RollbackException;
};

// Object instance structure
struct _jc_javax_transaction_RollbackException$object {
	_jc_javax_transaction_RollbackException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_RollbackException$vtype	*vtype;
	_jc_javax_transaction_RollbackException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_RollbackException$vtype _jc_javax_transaction_RollbackException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_RollbackException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_RollbackException$class_object;

#endif	/* _JC_javax_transaction_RollbackException_H_ */
